@@ -1,10 +1,10 @@
 from ngutils.functions import *
 
-__version__ = '0.9.7'
+__version__ = '0.9.9'
 
 __all__ = [
     'accel_steps',
-    'phrase_build',
+    'build_phrase',
     'read_urls_contents',
     'tune_steps',
     'view_types',
